<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="80px">
      <el-form-item label="企业名称" prop="companyName">
        <el-input v-model="queryParams.companyName" placeholder="请输入企业名称" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="企业编号" prop="companyCode">
        <el-input v-model="queryParams.companyCode" placeholder="请输入企业编号" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="企业类型" prop="status">
        <el-select v-model="queryParams.status" placeholder="企业类型" clearable style="width: 200px">
          <el-option v-for="dict in sys_normal_disable" :key="dict.value" :label="dict.label" :value="dict.value" />
        </el-select>
      </el-form-item>
      <el-form-item label="联系人" prop="companyUser">
        <el-input v-model="queryParams.companyUser" placeholder="请输入联系人" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="手机号" prop="companyPhone">
        <el-input v-model="queryParams.companyPhone" type="number" placeholder="请输入手机号" clearable style="width: 200px" @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="审核" prop="checkStatus">
        <el-select v-model="queryParams.checkStatus" placeholder="审核类型" clearable style="width: 200px">
          <el-option v-for="dict in options.checkOptions" :key="dict.value" :label="dict.label" :value="dict.value" />
        </el-select>
      </el-form-item>
      <el-form-item label="状态" prop="companyStatus">
        <el-select v-model="queryParams.companyStatus" placeholder="状态" clearable style="width: 200px">
          <el-option v-for="dict in options.companyStatus" :key="dict.value" :label="dict.label" :value="dict.value" />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="handleAdd()" v-hasPermi="['system:dept:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="exportExcel" v-hasPermi="['system:dept:add']">导入</el-button>
      </el-col>
      <!-- <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="exportRecordComOpen" v-hasPermi="['system:dept:add']">导入记录</el-button>
      </el-col> -->
      <!-- <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar> -->
    </el-row>

    <el-table
      v-if="refreshTable"
      v-loading="loading"
      :data="deptList"
      row-key="deptId"
      :default-expand-all="isExpandAll"
      :tree-props="{ children: 'children', hasChildren: 'hasChildren' }"
    >
      <el-table-column  prop="companyName" label="企业名称" minWidth="300"></el-table-column>
      <el-table-column prop="companyName" label="企业类型" width="200"></el-table-column>
      <el-table-column prop="companyUser" label="联系人" width="180"></el-table-column>
      <el-table-column prop="companyCode" label="统一社会信用代码" width="180"></el-table-column>
      <el-table-column prop="companyPhone" label="手机号码" width="120"></el-table-column>
      <el-table-column prop="createTime" label="创建时间" width="200"></el-table-column>
      <el-table-column prop="" label="来源" width="100">
        <template #default="scope">
          {{ scopeList[scope.row.isImport] }}
        </template>
      </el-table-column>
      <el-table-column prop="checkStatus" label="审核" width="100">
        <template #default="scope">
          {{ judgeStatus[scope.row.checkStatus] }}
        </template>
      </el-table-column>
      <el-table-column prop="companyStatus" label="状态" width="100">
        <template #default="scope">
          <!-- {{ companyStatus[scope.row.companyStatus] }} -->
            <el-switch v-if="scope.row.companyId" v-model="scope.row.companyStatus" @change="changeCompanyNews(scope.row, $event)" :active-value="1" :inactive-value="0"></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" fixed="right" class-name="small-padding fixed-width" width="240">
        <template #default="scope">
          <el-link type="primary" v-if="scope.row.checkStatus < 2" v-hasPermi="['sys:company:check']" @click="checkJudge(scope.row)">审核</el-link>
          <el-divider direction="vertical" v-hasPermi="['sys:company:check']" v-if="scope.row.checkStatus < 2"/>
          <el-link type="primary" v-if="scope.row.checkStatus == 2" @click="createQrcodeHandler(scope.row)">二维码</el-link>
          <el-divider direction="vertical" />
          <el-link type="primary" @click="handleAdd(scope.row)">编辑</el-link>
          <el-divider direction="vertical" />
          <el-link type="primary" @click="handleDelete(scope.row)">删除</el-link>
         </template>
      </el-table-column>
    </el-table>
    <pagination v-show="queryParams.total > 0" :total="queryParams.total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改对话框 -->
    <el-dialog :title="title" v-model="open" width="600px" append-to-body>
      <el-form ref="deptRef" :model="form" :rules="rules" label-width="140px">
        <el-form-item label="企业名称" prop="companyName">
          <el-input placeholder="请输入企业名称" v-model="form.companyName"></el-input>
        </el-form-item>
        <el-form-item label="联系人"  prop="companyUser">
          <el-input placeholder="请输入联系人" v-model="form.companyUser"></el-input>
        </el-form-item>
        <el-form-item label="手机号码" prop="companyPhone">
          <el-input placeholder="请输入手机号码" v-model="form.companyPhone"></el-input>
        </el-form-item>
        <el-form-item label="统一社会信用代码" prop="companyCode">
          <el-input placeholder="请输入统一社会信用代码" v-model="form.companyCode"></el-input>
        </el-form-item>
        <el-form-item label="营业执照" prop="companyImg">
          <!-- <el-input placeholder="请输入营业执照"  v-model="form.companyImg"></el-input> -->
          <FileUpload :limit="1" :fileType="['png', 'jpg', 'jpeg']" v-model="form.companyImg"></FileUpload>
        </el-form-item>
        <el-form-item label="企业地址" prop="companyAddress">
          <el-input placeholder="请输入企业地址"  v-model="form.companyAddress"></el-input>
        </el-form-item>
        <el-form-item label="状态">
          <el-switch v-model="form.companyStatus" :active-value="1" :inactive-value="0"></el-switch>
        </el-form-item>
        <el-form-item label="备注">
          <el-input placeholder="请输入备注" v-model="form.remark"></el-input>
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
    <exportExcelCom ref="exporttem" @resList="resList"></exportExcelCom>
    <exportRecord ref="exportRecordCom" :recordRow="recordRow" @uploadList="getList"></exportRecord>
    <judgeCom ref="judgeComRef"></judgeCom>
    <createQrcode ref="createQrcodeRef"></createQrcode>
  </div>
</template>

<script setup name="Dept">
import FileUpload from '@/components/ImageUpload/index'
import exportRecord from './components/exportRecord'
import createQrcode from './components/createQrcode'
import judgeCom from './components/judge'
import { listCompany,addCompany, updateCompany, delCompany } from "@/api/system/company/company";
import exportExcelCom from './components/export'
import { computed } from "vue";
import { judgeStatus, companyStatus, scopeList } from '@/utils/mapList/index.ts'
import useSettingsStore from "@/store/modules/settings";
const thcolor = computed(() => useSettingsStore().theme);
const { proxy } = getCurrentInstance();
const { sys_normal_disable } = proxy.useDict("sys_normal_disable");
const deptList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const title = ref("");
const deptOptions = ref([]);
const isExpandAll = ref(false);
const refreshTable = ref(true);
const exporttem = ref()
const exportRecordCom = ref()
const judgeComRef = ref()
const createQrcodeRef = ref()
const options = reactive({
  // -1拒绝，0待审批，1审批中，2通过	
  checkOptions: [
    {
      label: '拒绝',
      value: -1
    },
    {
      label: '待审批',
      value: 0
    },
    {
      label: '审批中',
      value: 1
    },
    {
      label: '通过',
      value: 2
    }
  ],
  companyStatus: [
  {
      label: '正常',
      value: 1
    },
    {
      label: '禁用',
      value: 0
    },
  ],
  socreList: [
  {
      label: '导入',
      value: 1
    },
    {
      label: '注册',
      value: 0
    },
  ]
})
const data = reactive({
  form: {},
  queryParams: {
    deptName: undefined,
    status: undefined,
    deptType: undefined,
    pageNum: 1,
    pageSize: 10,
    total: 1
  },
  rules: {
    companyName: [{ required: true, message: "企业名称不能为空", trigger: "blur" }],
    companyUser: [{ required: true, message: "联系人不能为空", trigger: "blur" }],
    companyPhone: [{ required: true, message: "手机号码不能为空", trigger: "blur" }, {
      pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/, message: "请输入正确的手机号码", trigger: "blur"
    }],
    companyCode: [{ required: true, message: "统一社会信用代码不能为空", trigger: "blur" }],
    companyImg: [{ required: true, message: "营业执照不能为空", trigger: "blur" }],
    companyAddress: [{ required: true, message: "企业地址不能为空", trigger: "blur" }],

    // email: [{ type: "email", message: "请输入正确的邮箱地址", trigger: ["blur", "change"] }],
    // phone: [{ pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/, message: "请输入正确的手机号码", trigger: "blur" }],
  },
});

const { queryParams, form, rules } = toRefs(data);
// const dispDeptType = computed(() => (e) => {
//   return dept_type.value.find((f) => f.value == e).label;
// });
const recordRow = ref([])
/** 查询企业列表 */
function getList() {
  loading.value = true;
  listCompany(queryParams.value).then((response) => {
    deptList.value = response.rows
    data.queryParams.total = response.total
    loading.value = false;
  });
}
/** 取消按钮 */
function cancel() {
  open.value = false;
  reset();
}
/** 表单重置 */
function reset() {
  form.value = {
    deptId: undefined,
    parentId: undefined,
    deptName: undefined,
    orderNum: 0,
    leader: undefined,
    phone: undefined,
    email: undefined,
    status: "0",
    deptType: undefined,
  };
  proxy.resetForm("deptRef");
}
const queryRef = ref()
/** 搜索按钮操作 */
function handleQuery() {
  getList();
}
/** 重置按钮操作 */
function resetQuery() {
  queryRef.value.resetFields();
  handleQuery();
}
/** 新增按钮操作 */
function handleAdd(row) {
  if(row) {
    form.value = row
    title.value = "编辑企业";
  } else {
    form.value = {}
    title.value = "添加企业";
  }
  open.value = true;
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["deptRef"].validate((valid) => {
    if (valid) {
      if (form.value.companyId != undefined) {
        updateCompany(form.value).then((response) => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addCompany(form.value).then((response) => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}
/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal
    .confirm('是否确认删除该数据?')
    .then(function () {
      return delCompany({delId: row.companyId});
    })
    .then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
    })
    .catch(() => {});
}
// 修改企业信息
function changeCompanyNews(row, event) {
  if(loading.value){
    return
  }
  updateCompany(row).then(val => {
    proxy.$modal.msgSuccess("修改成功");
    getList();
  })
}
// 导入模板
function exportExcel() {
  exporttem.value.openDialog()
}
// 导入记录
function exportRecordComOpen() {
  exportRecordCom.value.openDialog()
}
function resList(row) {
  recordRow.value = row
  exportRecordCom.value.openDialog()
}
function checkJudge(row) {
  judgeComRef.value.openDialog(row)
}
function createQrcodeHandler(row) {
  createQrcodeRef.value.openDialog(row)
}
getList();
</script>
